#!/usr/bin/env python

"""
test to demonstrate name attribute in various file handlers
"""

import sys

if __name__ == "__main__":
    if len(sys.argv) < 2:
        print("specify file name")

    file_name = sys.argv[1]

    if file_name.endswith("gz"):
        import gzip
        f = gzip.open(file_name)

        name = "?"

        if hasattr(f, "name"):
            name = f.name

        print("file '{}' is opened with GzipFile and name is: '{}'".format(file_name, name))

    elif file_name.endswith("bz2"):
        import bz2
        f = None

        try:
            f = bz2.open(file_name)
        except AttributeError:
            f = bz2.BZ2File(file_name)

        name = "?"

        if hasattr(f, "name"):
            name = f.name

        print("file '{}' is opened with BZip2File and name is: '{}'".format(file_name, name))

    else:
        import io
        f = io.open(file_name)

        name = "?"

        if hasattr(f, "name"):
            name = f.name

        print("file '{}' is opened with io.open and name is: '{}'".format(file_name, name))

# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
